==> BittenBaum-3.00.tar.bz2: BittenBaum-3.00/gui/BittenBaum/Smdn.Applications.BittenBaum.UI/GraphOptionDialog.cs <==
//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2003-2013 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Drawing;
using System.Windows.Forms;

using Smdn.Imaging;
using Smdn.Applications.BittenBaum.Analysis;
using Smdn.Applications.BittenBaum.Rendering;

namespace Smdn.Applications.BittenBaum.UI {
  public partial class GraphOptionDialog : Form {
    public ColoringMode ColoringMode {
      get {
        if (radioButtonColorMode_Directory.Checked)
          return ColoringMode.Directory;
        else if (radioButtonColorMode_DirectoryBaumkuchen.Checked)
          return ColoringMode.DirectoryBaumkuchen;
        else if (radioButtonColorMode_Volume.Checked)
          return ColoringMode.Volume;
        else
          return ColoringMode.Directory; // as default
      }
      set {
        switch (value) {
          case ColoringMode.Volume:
            radioButtonColorMode_Volume.Checked = true;
            break;

          case ColoringMode.DirectoryBaumkuchen:
            radioButtonColorMode_DirectoryBaumkuchen.Checked = true;
            break;

          case ColoringMode.Directory:
          default:
            radioButtonColorMode_Directory.Checked = true;
            break;
        }
      }
    }

    public int ColoringHue {
      get { return (int)trackBarColorModeVolumeHue.Value; }
      set { trackBarColorModeVolumeHue.Value = value; }
    }

    public bool DrawHighQuality {
      get { return !checkBoxDrawHighPriority.Checked; }
      set { checkBoxDrawHighPriority.Checked = !value; }
    }

    public bool DrawSmallEntries {
      get { return checkBoxDrawSmallEntries.Checked; }
      set { checkBoxDrawSmallEntries.Checked = value; }
    }

    public Color GraphBackgroundColor {
      get { 
        if (radioButtonBackgroundColor_White.Checked)
          return Color.White;
        else if (radioButtonBackgroundColor_Black.Checked)
          return Color.Black;
        else
          return Color.White; // as default
      }
      set {
        if (value == Color.White)
          radioButtonBackgroundColor_White.Checked = true;
        else if (value == Color.Black)
          radioButtonBackgroundColor_Black.Checked = true;
        else
          radioButtonBackgroundColor_White.Checked = true; // as default
      }
    }

    public Color GraphTextColor {
      get { 
        if (radioButtonBackgroundColor_White.Checked)
          return Color.Black;
        else if (radioButtonBackgroundColor_Black.Checked)
          return Color.White;
        else
          return Color.Black; // as default
      }
    }

    public DirectoryEntryCompareMode EntryCompareMode {
      get {
        if (radioButtonComparison_ByName.Checked)
          return DirectoryEntryCompareMode.ByName;
        else if (radioButtonComparison_BySize.Checked)
          return DirectoryEntryCompareMode.BySize;
        else
          return DirectoryEntryCompareMode.ByName; // as default
      }
      set {
        switch (value) {
          case DirectoryEntryCompareMode.BySize:
            radioButtonComparison_BySize.Checked = true;
            break;

          case DirectoryEntryCompareMode.ByName:
          default:
            radioButtonComparison_ByName.Checked = true;
            break;
        }
      }
    }

    public bool CompareEntryType {
      get { return checkBoxCompareEntryType.Checked; }
      set { checkBoxCompareEntryType.Checked = value; }
    }

    public int FontSize {
      get { return (int)numericUpDownFontSize.Value; }
      set { numericUpDownFontSize.Value = value; }
    }

    public int OutputSize {
      get { return (int)numericUpDownOutputSize.Value; }
      set { numericUpDownOutputSize.Value = value; }
    }

    public bool DrawNames {
      get { return checkBoxDrawNames.Checked; }
      set { checkBoxDrawNames.Checked = value; }
    }

    public bool DrawStatistics {
      get { return checkBoxDrawStatistics.Checked; }
      set { checkBoxDrawStatistics.Checked = value; }
    }

    public float InnerDiameterPercent {
      get { return trackBarInnerDiameterPercent.Value / 100.0f; }
      set { trackBarInnerDiameterPercent.Value = (int)(value * 100.0f); }
    }

    public GraphOptionDialog()
    {
      InitializeComponent();

      trackBarColorModeVolumeHue.ValueChanged += delegate {
        UpdateColoringHuePreview();
      };

      trackBarInnerDiameterPercent.ValueChanged += delegate {
        UpdateInnerDiameterPercentValue();
      };

      radioButtonColorMode_Volume.CheckedChanged += delegate {
        SetEnabilityOfColorModeVolumeOptions();
      };
    }

    public DialogResult ShowDialog(IWin32Window owner,
                                   bool configureCompareOptions,
                                   bool configureOutputOptions)
    {
      if (!configureCompareOptions) {
        groupBoxCompareOptions.Visible = false;
        Height -= groupBoxCompareOptions.Height;
        groupBoxOutputOptions.Top = panelLocator.Top;
      }

      if (!configureOutputOptions) {
        groupBoxOutputOptions.Visible = false;
        Height -= groupBoxOutputOptions.Height;
        groupBoxCompareOptions.Top = panelLocator.Top;
      }

      if (Runtime.IsRunningOnMono) {
        radioButtonColorMode_DirectoryBaumkuchen.Enabled = false;

        if (radioButtonColorMode_DirectoryBaumkuchen.Checked)
          radioButtonColorMode_Directory.Checked = true;
      }

      UpdateColoringHuePreview();
      UpdateInnerDiameterPercentValue();
      SetEnabilityOfColorModeVolumeOptions();

      return ShowDialog(owner);
    }

    private void SetEnabilityOfColorModeVolumeOptions()
    {
      panelColorModeVolumeOptions.Enabled = radioButtonColorMode_Volume.Checked;
    }

    private void UpdateColoringHuePreview()
    {
      var color = new HsvColor((int)trackBarColorModeVolumeHue.Value, 255, 255);

      pictureBoxColorModeVolumeHuePreview.BackColor = ColorModel.ToRgb(color);
    }

    private void UpdateInnerDiameterPercentValue()
    {
      labelInnerDiameterPercent.Text = trackBarInnerDiameterPercent.Value.ToString() + "%";
    }
  }
}

==> BittenBaum-3.01.tar.bz2: BittenBaum-3.01/gui/BittenBaum/Smdn.Applications.BittenBaum.UI/GraphOptionDialog.cs <==
//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2003-2013 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Drawing;
using System.Windows.Forms;

using Smdn.Imaging;
using Smdn.Applications.BittenBaum.Analysis;
using Smdn.Applications.BittenBaum.Rendering;

namespace Smdn.Applications.BittenBaum.UI {
  public partial class GraphOptionDialog : Form {
    public ColoringMode ColoringMode {
      get {
        if (radioButtonColorMode_Directory.Checked)
          return ColoringMode.Directory;
        else if (radioButtonColorMode_DirectoryBaumkuchen.Checked)
          return ColoringMode.DirectoryBaumkuchen;
        else if (radioButtonColorMode_Volume.Checked)
          return ColoringMode.Volume;
        else
          return ColoringMode.Directory; // as default
      }
      set {
        switch (value) {
          case ColoringMode.Volume:
            radioButtonColorMode_Volume.Checked = true;
            break;

          case ColoringMode.DirectoryBaumkuchen:
            radioButtonColorMode_DirectoryBaumkuchen.Checked = true;
            break;

          case ColoringMode.Directory:
          default:
            radioButtonColorMode_Directory.Checked = true;
            break;
        }
      }
    }

    public int ColoringHue {
      get { return (int)trackBarColorModeVolumeHue.Value; }
      set { trackBarColorModeVolumeHue.Value = value; }
    }

    public bool DrawHighQuality {
      get { return !checkBoxDrawHighPriority.Checked; }
      set { checkBoxDrawHighPriority.Checked = !value; }
    }

    public bool DrawSmallEntries {
      get { return checkBoxDrawSmallEntries.Checked; }
      set { checkBoxDrawSmallEntries.Checked = value; }
    }

    public Color GraphBackgroundColor {
      get { 
        if (radioButtonBackgroundColor_White.Checked)
          return Color.White;
        else if (radioButtonBackgroundColor_Black.Checked)
          return Color.Black;
        else
          return Color.White; // as default
      }
      set {
        if (value == Color.White)
          radioButtonBackgroundColor_White.Checked = true;
        else if (value == Color.Black)
          radioButtonBackgroundColor_Black.Checked = true;
        else
          radioButtonBackgroundColor_White.Checked = true; // as default
      }
    }

    public Color GraphTextColor {
      get { 
        if (radioButtonBackgroundColor_White.Checked)
          return Color.Black;
        else if (radioButtonBackgroundColor_Black.Checked)
          return Color.White;
        else
          return Color.Black; // as default
      }
    }

    public DirectoryEntryCompareMode EntryCompareMode {
      get {
        if (radioButtonComparison_ByName.Checked)
          return DirectoryEntryCompareMode.ByName;
        else if (radioButtonComparison_BySize.Checked)
          return DirectoryEntryCompareMode.BySize;
        else
          return DirectoryEntryCompareMode.ByName; // as default
      }
      set {
        switch (value) {
          case DirectoryEntryCompareMode.BySize:
            radioButtonComparison_BySize.Checked = true;
            break;

          case DirectoryEntryCompareMode.ByName:
          default:
            radioButtonComparison_ByName.Checked = true;
            break;
        }
      }
    }

    public bool CompareEntryType {
      get { return checkBoxCompareEntryType.Checked; }
      set { checkBoxCompareEntryType.Checked = value; }
    }

    public bool CalculateRangeByDriveUsage {
      get { return checkBoxCalculateRangeByDriveUsage.Checked; }
      set { checkBoxCalculateRangeByDriveUsage.Checked = value; }
    }

    public int FontSize {
      get { return (int)numericUpDownFontSize.Value; }
      set { numericUpDownFontSize.Value = value; }
    }

    public int OutputSize {
      get { return (int)numericUpDownOutputSize.Value; }
      set { numericUpDownOutputSize.Value = value; }
    }

    public bool DrawNames {
      get { return checkBoxDrawNames.Checked; }
      set { checkBoxDrawNames.Checked = value; }
    }

    public bool DrawStatistics {
      get { return checkBoxDrawStatistics.Checked; }
      set { checkBoxDrawStatistics.Checked = value; }
    }

    public float InnerDiameterPercent {
      get { return trackBarInnerDiameterPercent.Value / 100.0f; }
      set { trackBarInnerDiameterPercent.Value = (int)(value * 100.0f); }
    }

    public GraphOptionDialog()
    {
      InitializeComponent();

      trackBarColorModeVolumeHue.ValueChanged += delegate {
        UpdateColoringHuePreview();
      };

      trackBarInnerDiameterPercent.ValueChanged += delegate {
        UpdateInnerDiameterPercentValue();
      };

      radioButtonColorMode_Volume.CheckedChanged += delegate {
        SetEnabilityOfColorModeVolumeOptions();
      };
    }

    public DialogResult ShowDialog(IWin32Window owner,
                                   bool configureGraphingOptions,
                                   bool configureOutputOptions)
    {
      if (!configureGraphingOptions) {
        groupBoxGraphingOptions.Visible = false;
        Height -= groupBoxGraphingOptions.Height;
        groupBoxOutputOptions.Top = panelLocator.Top;
      }

      if (!configureOutputOptions) {
        groupBoxOutputOptions.Visible = false;
        Height -= groupBoxOutputOptions.Height;
        groupBoxGraphingOptions.Top = panelLocator.Top;
      }

      if (Runtime.IsRunningOnMono) {
        radioButtonColorMode_DirectoryBaumkuchen.Enabled = false;

        if (radioButtonColorMode_DirectoryBaumkuchen.Checked)
          radioButtonColorMode_Directory.Checked = true;
      }

      UpdateColoringHuePreview();
      UpdateInnerDiameterPercentValue();
      SetEnabilityOfColorModeVolumeOptions();

      return ShowDialog(owner);
    }

    private void SetEnabilityOfColorModeVolumeOptions()
    {
      panelColorModeVolumeOptions.Enabled = radioButtonColorMode_Volume.Checked;
    }

    private void UpdateColoringHuePreview()
    {
      var color = new HsvColor((int)trackBarColorModeVolumeHue.Value, 255, 255);

      pictureBoxColorModeVolumeHuePreview.BackColor = ColorModel.ToRgb(color);
    }

    private void UpdateInnerDiameterPercentValue()
    {
      labelInnerDiameterPercent.Text = trackBarInnerDiameterPercent.Value.ToString() + "%";
    }
  }
}
